@@ -4,8 +4,8 @@
 /* -------------------------- Gammu specific ---------------------------- */
 
 /* Version of package */
-#define GAMMU_VERSION "1.40.0"
-#define GAMMU_VERSION_NUM 14000
+#define GAMMU_VERSION "1.41.0"
+#define GAMMU_VERSION_NUM 14100
 
 /* Define if want DEBUG info */
 /* #undef DEBUG */
@@ -22,7 +22,7 @@
 /* FBUS2 to use with cable with PL2303 chip (init done using AT commands) */
 #define GSM_ENABLE_FBUS2PL2303
 /* FBUS2 to use with bluetooth legacy device (init done using AT commands) */
-#define GSM_ENABLE_FBUS2BLUE
+/* #undef GSM_ENABLE_FBUS2BLUE */
 /* FBUS2 to use with direct infrared device */
 /* #undef GSM_ENABLE_FBUS2IRDA */
 
@@ -34,7 +34,7 @@
 #define GSM_ENABLE_DKU5FBUS2
 
 /* PHONET FBUS to use with bluetooth legacy device */
-#define GSM_ENABLE_PHONETBLUE
+/* #undef GSM_ENABLE_PHONETBLUE */
 
 /* AT protocol */
 #define GSM_ENABLE_AT
@@ -51,17 +51,17 @@
 /* Infrared */
 /* #undef GSM_ENABLE_IRDAGNAPBUS */
 
-#define GSM_ENABLE_BLUEGNAPBUS
+/* #undef GSM_ENABLE_BLUEGNAPBUS */
 
 #define GSM_ENABLE_S60
 /* Bluetooth stack (like Bluez). FBUS2 (init done using AT commands) */
-#define GSM_ENABLE_BLUEFBUS2
+/* #undef GSM_ENABLE_BLUEFBUS2 */
 /* Bluetooth stack (like Bluez). PHONET FBUS */
-#define GSM_ENABLE_BLUEPHONET
+/* #undef GSM_ENABLE_BLUEPHONET */
 /* Blueooth stack (like Bluez). AT commands */
-#define GSM_ENABLE_BLUEAT
+/* #undef GSM_ENABLE_BLUEAT */
 /* Blueooth stack (like Bluez). OBEX */
-#define GSM_ENABLE_BLUEOBEX
+/* #undef GSM_ENABLE_BLUEOBEX */
 
 /* --------------------------- Phone modules (specific) ----------------- */
 
@@ -160,7 +160,7 @@
 #define HAVE_PTHREAD
 #endif
 #ifndef HAVE_SIGTIMEDWAIT
-#define HAVE_SIGTIMEDWAIT
+/* #undef HAVE_SIGTIMEDWAIT */
 #endif
 #ifndef HAVE_SYS_IOCTL_H
 #define HAVE_SYS_IOCTL_H
@@ -169,9 +169,9 @@
 /* #undef HAVE_MYSQL_MYSQL_H */
 #endif
 /* ODBC support */
-#define ODBC_FOUND
+/* #undef ODBC_FOUND */
 /* Do we have libdbi ? */
-/* #undef LIBDBI_FOUND */
+#define LIBDBI_FOUND
 #ifndef HAVE_POSTGRESQL_LIBPQ_FE_H
 /* #undef HAVE_POSTGRESQL_LIBPQ_FE_H */
 #endif
@@ -275,7 +275,7 @@
 #define HAVE_STRCASESTR 
 #endif
 #ifndef HAVE_STRCHRNUL
-#define HAVE_STRCHRNUL 
+/* #undef HAVE_STRCHRNUL */
 #endif
 #ifndef HAVE_STRTOULL
 #define HAVE_STRTOULL
@@ -349,7 +349,7 @@
 
 /* Iconv support */
 #define ICONV_FOUND
-#define ICONV_SECOND_ARGUMENT_IS_CONST
+/* #undef ICONV_SECOND_ARGUMENT_IS_CONST */
 
 /* CURL support */
 #define CURL_FOUND
@@ -358,10 +358,10 @@
 /* #undef BLUEZ_FOUND */
 
 /* Do we have libusb-1.0 ? */
-/* #undef LIBUSB_FOUND */
+#define LIBUSB_FOUND
 
 /* Will be used BSD Bluetooth stack ? */
-#define BSD_BLUE_FOUND
+/* #undef BSD_BLUE_FOUND */
 
 /* Will be used OSX Bluetooth stack ? */
 /* #undef OSX_BLUE_FOUND */
@@ -369,19 +369,19 @@
 /* #undef OSX_BLUE_2_0 */
 
 /* Enable Bluetooth channnel searching? */
-#define BLUETOOTH_RF_SEARCHING
+/* #undef BLUETOOTH_RF_SEARCHING */
 
 /* Enable Glib */
-/* #undef Glib_FOUND */
+#define Glib_FOUND
 
 /* spawnv argument type */
 /* #undef SPAWNV_ARGUMENT_IS_CONST */
 
 /* Path where locales will be installed */
-#define LOCALE_PATH "/usr/pkg/share/locale"
+#define LOCALE_PATH "/usr/local/share/locale"
 
 /* Path where locales will be installed */
-#define GAMMU_DATA_PATH "/usr/pkg/share/gammu"
+#define GAMMU_DATA_PATH "/usr/local/share/gammu"
 
 /* Most winapi crap can be used as well from Cygwin */
 #if defined(WIN32) || defined(__CYGWIN__)
